@@ -1,4 +1,4 @@
-ranjan_optim <- function(x, model, T, method.param=NULL){
+ranjan_optim <- function(x, model, T, method.param=1){
 	
 	y <- t(x)
   if((nrow(y)==1) && (ncol(y)==model@d)){
@@ -10,7 +10,7 @@ ranjan_optim <- function(x, model, T, method.param=NULL){
   }
 	
 	krig <- predict_nobias_km(object=model,newdata=as.data.frame(z),type="UK",se.compute=TRUE)
-	if(is.null(method.param)) method.param <- 1
+	
 	mk    <- krig$mean; sk    <- krig$sd; alpha <- method.param	
 	t <- (mk-T)/sk; tplus <- t + alpha; tminus <- t - alpha
 	
